pub(crate) enum FilterSelection<'a> {
None,
All {
len: usize,
},
Slices(FilterIterator<Copied<Iter<'a, (usize, usize)>>, SlicesIterator<'a>>),
Indices(FilterIterator<Copied<Iter<'a, usize>>, IndexIterator<'a>>),
}Expand description
Borrowed description of which rows a FilterPredicate selects.
This is used for filtering multiple arrays with the same predicate without having to clone the predicate’s internal data structures (e.g. the list of indices or slices).
Variants
None
No rows are selected
All
All len rows are selected
Slices(FilterIterator<Copied<Iter<'a, (usize, usize)>>, SlicesIterator<'a>>)
Iterator of (start, end) slices, each a run of contiguous selected rows
Indices(FilterIterator<Copied<Iter<'a, usize>>, IndexIterator<'a>>)
Iterator of the indices of the selected rows