take_union_type_ids

Function take_union_type_ids 

fn take_union_type_ids<IndexType: ArrowPrimitiveType>(
    fields: &UnionFields,
    type_ids: &ScalarBuffer<i8>,
    indices: &PrimitiveArray<IndexType>,
) -> Result<(ScalarBuffer<i8>, Option<i8>), ArrowError>
Takes union type ids, substituting a child that can represent a null for null take indices.

Union arrays do not have a top-level null bitmap. A null is represented by selecting a child that can store a null value. In particular, a null index cannot fall back to type id 0, as unions are not required to have such a child.

Returns the taken type ids and, when indices contains nulls, the type id used to represent those nulls.