pub struct TakeOptions {
pub check_bounds: bool,
}Expand description
Options that define how take should behave
Fields
check_bounds: boolPerform bounds check before taking indices from values.
If enabled, an ArrowError is returned if the indices are out of bounds.
If not enabled, and indices exceed bounds, the kernel will panic.