fn field_can_represent_take_null(field: &FieldRef) -> boolExpand description
Whether field can physically store a newly introduced null.
Union and RunEndEncoded have no top-level validity bitmap, so a null must be represented by a descendant that is marked nullable. A field marked nullable is not sufficient if its nested type cannot store a null.