fn take_sparse_union_child<IndexType: ArrowPrimitiveType, const CHECKED: bool>(
values: &dyn Array,
represent_nulls: bool,
indices: &PrimitiveArray<IndexType>,
) -> Result<ArrayRef, ArrowError>Expand description
Takes a sparse union child for indices.
Null take indices select one child that can represent a null
(take_union_type_ids). Values in the other children at those positions
are unspecified, so they are taken with dummy indices instead of introducing
nulls that would contradict field metadata.