fn take_union_type_ids<IndexType: ArrowPrimitiveType>(
fields: &UnionFields,
type_ids: &ScalarBuffer<i8>,
indices: &PrimitiveArray<IndexType>,
) -> Result<ScalarBuffer<i8>, ArrowError>Expand description
Takes union type ids, substituting a valid type id for null take indices.
Union arrays do not have a top-level null bitmap. A null is represented by selecting an
arbitrary valid child type id with a null value in that child. In particular, a null index
cannot fall back to type id 0, as unions are not required to have such a child.